#
# spec file for package ghc-regex-tdfa
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name regex-tdfa
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.3.2.4
Release:        1.1
Summary:        Pure Haskell Tagged DFA Backend for "Text.Regex" (regex-base)
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-parsec-prof
BuildRequires:  ghc-regex-base-devel
BuildRequires:  ghc-regex-base-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-doctest-parallel-devel
BuildRequires:  ghc-doctest-parallel-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-utf8-string-devel
BuildRequires:  ghc-utf8-string-prof
%endif

%description
This package provides a pure Haskell "Tagged" DFA regex engine for
<//hackage.haskell.org/package/regex-base regex-base>. This implementation was
inspired by the algorithm (and Master's thesis) behind the regular expression
library known as <https://github.com/laurikari/tre/ TRE or libtre>.

Please consult the "Text.Regex.TDFA" module for API documentation including a
tutorial with usage examples; see also
<https://wiki.haskell.org/Regular_expressions> for general information about
regular expression support in Haskell.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Fri May  9 2025 Peter Simons <psimons@suse.com>
- Update regex-tdfa to version 1.3.2.4.
  [#]## 1.3.2.4
  _2025-05-09 Andreas Abel_
  - Fix definition of `[[:graph:]]` character class ([#66](https://github.com/haskell-hvr/regex-tdfa/issues/66))
  - Tested with GHC 8.0 - 9.12.2
* Sun Mar  2 2025 Peter Simons <psimons@suse.com>
- Update regex-tdfa to version 1.3.2.3.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/regex-tdfa-1.3.2.3/src/CHANGELOG.md
* Tue Apr 16 2024 Peter Simons <psimons@suse.com>
- Update regex-tdfa to version 1.3.2.2 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Sep 28 2023 Peter Simons <psimons@suse.com>
- Update regex-tdfa to version 1.3.2.2 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Aug 27 2023 Peter Simons <psimons@suse.com>
- Update regex-tdfa to version 1.3.2.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Aug  2 2023 Peter Simons <psimons@suse.com>
- Update regex-tdfa to version 1.3.2.2.
  [#]## 1.3.2.2
  _2023-08-02, Andreas Abel_
  - Fix return type in `memcpy` FFI signature ([#52](https://github.com/haskell-hvr/regex-tdfa/pull/52))
  - Refactor `regexec` to avoid partial functions `tail` and `(!0)`
  - Tested with GHC 7.4 - 9.8.1-alpha1
* Fri Jul  7 2023 Peter Simons <psimons@suse.com>
- Update regex-tdfa to version 1.3.2.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri May 19 2023 Peter Simons <psimons@suse.com>
- Update regex-tdfa to version 1.3.2.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/regex-tdfa-1.3.2.1/src/CHANGELOG.md
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Jul 18 2022 Peter Simons <psimons@suse.com>
- Update regex-tdfa to version 1.3.2.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/regex-tdfa-1.3.2/src/CHANGELOG.md
* Thu Jul 14 2022 Peter Simons <psimons@suse.com>
- Update regex-tdfa to version 1.3.1.3.
  [#]## 1.3.1.3
  _2022-07-14, Andreas Abel_
  - Fix an `undefined` in `Show PatternSet` [#37](https://github.com/haskell-hvr/regex-tdfa/issues/37))
  - Document POSIX character classes (e.g. `[[:digit:]]`)
  [#]## 1.3.1.2 Revision 1
  _2022-05-25, Andreas Abel_
  - Allow `base >= 4.17` (GHC 9.4)
* Wed May 25 2022 Peter Simons <psimons@suse.com>
- Update regex-tdfa to version 1.3.1.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Feb 19 2022 Peter Simons <psimons@suse.com>
- Update regex-tdfa to version 1.3.1.2.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/regex-tdfa-1.3.1.2/src/CHANGELOG.md
* Mon Jan 31 2022 Peter Simons <psimons@suse.com>
- Update regex-tdfa to version 1.3.1.1 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Aug 13 2021 psimons@suse.com
- Update regex-tdfa to version 1.3.1.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Jun  4 2021 psimons@suse.com
- Update regex-tdfa to version 1.3.1.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/regex-tdfa-1.3.1.1/src/CHANGELOG.md
* Sun Feb 21 2021 psimons@suse.com
- Update regex-tdfa to version 1.3.1.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Aug 31 2020 psimons@suse.com
- Update regex-tdfa to version 1.3.1.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Thu May  7 2020 Peter Simons <psimons@suse.com>
- Update Cabal file to get more accurate dependency information.
* Wed Jan  1 2020 psimons@suse.com
- Drop obsolete code that used to create a Setup.hs file. The new
  rpm macros do this automatically now.
* Wed Nov 27 2019 psimons@suse.com
- Update regex-tdfa to version 1.3.1.0.
  * Merge <http://hackage.haskell.org/package/regex-tdfa-text> into
    `regex-tdfa`; see <https://github.com/haskell-hvr/regex-tdfa/issues/4>.
  * Don't inject `ghc-options: -O2` by default anymore (see #7 for
    rationale) and introduce `force-O2` cabal flag to control the
    injection of `ghc-options: -O2`. Note that you can conveniently
    control optimization levels on a per-package granularity via
    `cabal.project` files; see [cabal's
    user-guide](https://cabal.readthedocs.io/en/latest/nix-local-build.html#configuring-builds-with-cabal-project)
    for more details.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sun Sep 29 2019 psimons@suse.com
- Update regex-tdfa to version 1.3.0.
  [#] 1.3.0
  Same as 1.2.3.3.
  See <https://github.com/ChrisKuklewicz/regex-tdfa/issues/29>.
  [#] 1.2.3.3 (deprecated)
  * Compatibility with GHC 8.8 and regex-base-0.9.4 (h/t @asr).
  * Turned `regex-tdfa-unittest` into a `regex-tdfa` testsuite.
* Fri May 10 2019 psimons@suse.com
- Update regex-tdfa to version 1.2.3.2.
  [#] 1.2.3.2
  * Significantly improved documentation (h/t William Yao).
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update regex-tdfa to version 1.2.3.1.
  [#] 1.2.3.1
  * Compatibility with `containers-0.6`.
* Mon May 14 2018 psimons@suse.com
- Update regex-tdfa to version 1.2.3.
  * Added `Semigroup` instances for some types.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.2.2 revision 0 with cabal2obs.
* Thu May 12 2016 mimi.vx@gmail.com
- update to 1.2.2
  * Now we don't reexport the problematic Show instance for functions.
* Sun Sep  6 2015 mimi.vx@gmail.com
- updated to 1.2.1
- spec regenerated with cabal-rpm
  * "Almost ghc-7.8" with the array 0.4 changes for Data.Array.Unsafe
  * Get Build-Depends from "Mon Jun 15 14:24:28 UTC 2015 by AdamBergmark to revision 1"
* Thu May 17 2012 peter.trommler@ohm-hochschule.de
- spec file template generated by cabal2spec-0.25.5
* Wed Jan 18 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
